Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(161)

Unified Diff: src/debug/debug-scopes.h

Issue 1834633003: [debugger] allow debug-evaluate to change stack and context values. (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: src/debug/debug-scopes.h
diff --git a/src/debug/debug-scopes.h b/src/debug/debug-scopes.h
index 80e19810e742f897731e9f80394304e6afba0207..e317082cb808dc0c5a3585aa00ee2749b7245887 100644
--- a/src/debug/debug-scopes.h
+++ b/src/debug/debug-scopes.h
@@ -75,8 +75,8 @@ class ScopeIterator {
// be an actual context.
Handle<Context> CurrentContext();
- // Populate the list with collected non-local variable names.
- void GetNonLocals(List<Handle<String> >* list_out);
+ // Populate the dictionary with collected non-local variable names.
+ Handle<NameDictionary> GetNonLocals();
bool ThisIsNonLocal();
« no previous file with comments | « src/debug/debug-evaluate.cc ('k') | src/debug/debug-scopes.cc » ('j') | src/factory.cc » ('J')

Powered by Google App Engine
This is Rietveld 408576698